@@ -1,4 +1,6 @@
-require 'nokogiri/diff/xml/node'
+# frozen_string_literal: true
+
+require_relative 'node'
 
 class Nokogiri::XML::Document < Nokogiri::XML::Node
 
